Capture Module
==============

This module contains screen and camera capture functionality.

Screen Capture
--------------

.. automodule:: fmusvid.capture.screen
   :members:
   :undoc-members:

Camera Capture
--------------

.. automodule:: fmusvid.capture.camera
   :members:
   :undoc-members:

Recorder
--------

.. automodule:: fmusvid.capture.recorder
   :members:
   :undoc-members:
